var _JUPYTERLAB;(()=>{"use strict";var e,t,r={921:(e,t,r)=>{var a={"./index":()=>r.e(568).then((()=>()=>r(568))),"./extension":()=>r.e(568).then((()=>()=>r(568))),"./style":()=>r.e(643).then((()=>()=>r(643)))},o=(e,t)=>(r.R=t,t=r.o(a,e)?a[e]():Promise.resolve().then((()=>{throw new Error('Module "'+e+'" does not exist in container.')})),r.R=void 0,t),n=(e,t)=>{if(r.S){var a="default",o=r.S[a];if(o&&o!==e)throw new Error("Container initialization failed as it has already been initialized with a different share scope");return r.S[a]=e,r.I(a,t)}};r.d(t,{get:()=>o,init:()=>n})}},a={};function o(e){var t=a[e];if(void 0!==t)return t.exports;var n=a[e]={id:e,exports:{}};return r[e](n,n.exports,o),n.exports}o.m=r,o.c=a,o.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return o.d(t,{a:t}),t},o.d=(e,t)=>{for(var r in t)o.o(t,r)&&!o.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},o.f={},o.e=e=>Promise.all(Object.keys(o.f).reduce(((t,r)=>(o.f[r](e,t),t)),[])),o.u=e=>e+"."+{568:"58d646ba30ad5cce43b0",643:"c1827be98afe184c4f03"}[e]+".js?v="+{568:"58d646ba30ad5cce43b0",643:"c1827be98afe184c4f03"}[e],o.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),o.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),e={},t="@jupyter-ai/chatgpt:",o.l=(r,a,n,i)=>{if(e[r])e[r].push(a);else{var u,l;if(void 0!==n)for(var d=document.getElementsByTagName("script"),s=0;s<d.length;s++){var c=d[s];if(c.getAttribute("src")==r||c.getAttribute("data-webpack")==t+n){u=c;break}}u||(l=!0,(u=document.createElement("script")).charset="utf-8",u.timeout=120,o.nc&&u.setAttribute("nonce",o.nc),u.setAttribute("data-webpack",t+n),u.src=r),e[r]=[a];var p=(t,a)=>{u.onerror=u.onload=null,clearTimeout(f);var o=e[r];if(delete e[r],u.parentNode&&u.parentNode.removeChild(u),o&&o.forEach((e=>e(a))),t)return t(a)},f=setTimeout(p.bind(null,void 0,{type:"timeout",target:u}),12e4);u.onerror=p.bind(null,u.onerror),u.onload=p.bind(null,u.onload),l&&document.head.appendChild(u)}},o.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},(()=>{o.S={};var e={},t={};o.I=(r,a)=>{a||(a=[]);var n=t[r];if(n||(n=t[r]={}),!(a.indexOf(n)>=0)){if(a.push(n),e[r])return e[r];o.o(o.S,r)||(o.S[r]={});var i=o.S[r],u="@jupyter-ai/chatgpt",l=[];return"default"===r&&((e,t,r,a)=>{var n=i[e]=i[e]||{},l=n[t];(!l||!l.loaded&&(1!=!l.eager?a:u>l.from))&&(n[t]={get:()=>o.e(568).then((()=>()=>o(568))),from:u,eager:!1})})("@jupyter-ai/chatgpt","0.5.0"),e[r]=l.length?Promise.all(l).then((()=>e[r]=1)):1}}})(),(()=>{var e;o.g.importScripts&&(e=o.g.location+"");var t=o.g.document;if(!e&&t&&(t.currentScript&&(e=t.currentScript.src),!e)){var r=t.getElementsByTagName("script");r.length&&(e=r[r.length-1].src)}if(!e)throw new Error("Automatic publicPath is not supported in this browser");e=e.replace(/#.*$/,"").replace(/\?.*$/,"").replace(/\/[^\/]+$/,"/"),o.p=e})(),(()=>{var e={758:0};o.f.j=(t,r)=>{var a=o.o(e,t)?e[t]:void 0;if(0!==a)if(a)r.push(a[2]);else{var n=new Promise(((r,o)=>a=e[t]=[r,o]));r.push(a[2]=n);var i=o.p+o.u(t),u=new Error;o.l(i,(r=>{if(o.o(e,t)&&(0!==(a=e[t])&&(e[t]=void 0),a)){var n=r&&("load"===r.type?"missing":r.type),i=r&&r.target&&r.target.src;u.message="Loading chunk "+t+" failed.\n("+n+": "+i+")",u.name="ChunkLoadError",u.type=n,u.request=i,a[1](u)}}),"chunk-"+t,t)}};var t=(t,r)=>{var a,n,[i,u,l]=r,d=0;if(i.some((t=>0!==e[t]))){for(a in u)o.o(u,a)&&(o.m[a]=u[a]);l&&l(o)}for(t&&t(r);d<i.length;d++)n=i[d],o.o(e,n)&&e[n]&&e[n][0](),e[n]=0},r=self.webpackChunk_jupyter_ai_chatgpt=self.webpackChunk_jupyter_ai_chatgpt||[];r.forEach(t.bind(null,0)),r.push=t.bind(null,r.push.bind(r))})(),o.nc=void 0;var n=o(921);(_JUPYTERLAB=void 0===_JUPYTERLAB?{}:_JUPYTERLAB)["@jupyter-ai/chatgpt"]=n})();